@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: jpeg.c 342 2023-10-06 23:39:02Z leres $ (XSE)
+ * @(#) $Id: jpeg.c 352 2024-12-28 21:09:42Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015, 2017, 2023
+ * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015, 2017, 2023, 2024
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -20,11 +20,6 @@
 
 #include <stdio.h>
 
-#include "gnuc.h"
-#ifdef HAVE_OS_PROTO_H
-#include "os-proto.h"
-#endif
-
 #include "exif.h"
 #include "jpeg.h"
 
