@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: webindex.c 345 2023-10-10 19:56:04Z leres $ (XSE)
+ * @(#) $Id: webindex.c 355 2025-05-30 23:19:48Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023
+ * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -16,7 +16,7 @@
  */
 #ifndef lint
 static const char copyright[] =
-    "@(#) Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023\nCraig Leres\n";
+    "@(#) Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025\nCraig Leres\n";
 #endif
 
 #include <sys/types.h>
@@ -780,8 +780,8 @@ processfile(FILE *f, struct webfile *wp, struct cf *cf,
 	case T_DIR:
 	case T_FILE:
 	case T_FLASH:
-	case T_MP3:
 	case T_HTML:
+	case T_MP3:
 	case T_PARENT:
 	case T_PDF:
 	case T_QT:
@@ -1064,13 +1064,17 @@ parsethumbnail(struct cf *cf, struct webfile *wp)
 	switch (wp->w_type) {
 
 	case T_BMP:
-		(void)parsebmp(wp->w_name, &wp->w_w, &wp->w_h, NULL);
-		flags |= W_HAVETN;
+		if (parsebmp(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
+			wp->w_type = T_FILE;
 		break;
 
 	case T_GIF:
-		(void)parsegif(wp->w_name, &wp->w_w, &wp->w_h, NULL);
-		flags |= W_HAVETN;
+		if (parsegif(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
+			wp->w_type = T_FILE;
 		break;
 
 	case T_JPEG:
@@ -1081,38 +1085,50 @@ parsethumbnail(struct cf *cf, struct webfile *wp)
 			location = NULL;
 			locationsize = 0;
 		}
-		(void)parsejpeg(wp->w_name, &wp->w_w, &wp->w_h, NULL,
-		    location, locationsize);
-		flags |= W_HAVETN;
+		if (parsejpeg(wp->w_name, &wp->w_w, &wp->w_h, NULL,
+		    location, locationsize))
+			flags |= W_HAVETN;
+		else
+			wp->w_type = T_FILE;
 		break;
 
 	case T_PBM:
 #ifdef HAVE_LIBPPM
-		(void)parsepbm(wp->w_name, &wp->w_w, &wp->w_h, NULL);
+		if (parsepbm(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
 #endif
-		flags |= W_HAVETN;
+			wp->w_type = T_FILE;
 		break;
 
 	case T_PNG:
-		(void)parsepng(wp->w_name, &wp->w_w, &wp->w_h, NULL);
-		flags |= W_HAVETN;
+		if (parsepng(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
+			wp->w_type = T_FILE;
 		break;
 
 	case T_TIFF:
 #ifdef HAVE_LIBTIFF
-		(void)parsetiff(wp->w_name, &wp->w_w, &wp->w_h, NULL);
+		if (parsetiff(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
 #endif
-		flags |= W_HAVETN;
+			wp->w_type = T_FILE;
 		break;
 
 	case T_XBM:
-		(void)parsexbm(wp->w_name, &wp->w_w, &wp->w_h, NULL);
-		flags |= W_HAVETN;
+		if (parsexbm(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
+			wp->w_type = T_FILE;
 		break;
 
 	case T_XWD:
-		(void)parsexwd(wp->w_name, &wp->w_w, &wp->w_h, NULL);
-		flags |= W_HAVETN;
+		if (parsexwd(wp->w_name, &wp->w_w, &wp->w_h, NULL))
+			flags |= W_HAVETN;
+		else
+			wp->w_type = T_FILE;
 		break;
 
 	default:
@@ -1657,7 +1673,7 @@ websort_time(const void *a1, const void *a2)
 	w1 = a1;
 	w2 = a2;
 	if (w1->w_timestamp == w2->w_timestamp)
-		return (websort_lex(a1, a2));
+		return (websort_lex(a2, a1));
 	return (w1->w_timestamp - w2->w_timestamp);
 }
 
